data(BoutrosRNAi2002)BoutrosRNAiExpression: For preprocessing we performed normalization on probe level using a variance
stabilizing transformation (Huber et al, 2002), and probe set summarization
using a median polish fit of an additive model (Irizarry et al, 2003).
BoutrosRNAiDiscrete: contains only the 68 genes more than two-fold up-regulated between negative and positive controls.
The continuous expression values are discretized to 1 (effect: closer to negative controls) and 0 (no effect: closer to positive controls).
BoutrosRNAiDens: log $p$-value density matrix for the 68 genes with more than two-fold up-regulated between negative and positive controls.
BoutrosRNAiLods: B-value matrix for the 68 genes with more than two-fold up-regulated between negative and positive controls.
BoutrosRNAiLogFC: matrix with log fold changes
nem.discretize data("BoutrosRNAi2002")
dim(BoutrosRNAiExpression)
dim(BoutrosRNAiDiscrete)
Run the code above in your browser using DataLab